LanguageCodeOfBackend enum

后端支持的语言代码。

Inheritance
Available extensions

Values

zhCn → const LanguageCodeOfBackend
const LanguageCodeOfBackend('zh-CN')
zhTw → const LanguageCodeOfBackend
const LanguageCodeOfBackend('zh-TW')
en → const LanguageCodeOfBackend
const LanguageCodeOfBackend('en')
fr → const LanguageCodeOfBackend
const LanguageCodeOfBackend('fr')
ja → const LanguageCodeOfBackend
const LanguageCodeOfBackend('ja')
de → const LanguageCodeOfBackend
const LanguageCodeOfBackend('de')
es → const LanguageCodeOfBackend
const LanguageCodeOfBackend('es')
ko → const LanguageCodeOfBackend
const LanguageCodeOfBackend('ko')

Properties

code String
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LanguageCodeOfBackend>
A constant List of the values in this enum, in order of their declaration.