SentenceInfo class

句子查询信息结构。

Constructors

SentenceInfo({required String sentence, required List<String> translations, required Uint8List audioData})
const

Properties

audioData Uint8List
  • 原始 sentence 的发音数据。
  • final
    hashCode int
    The hash code for this object.
    no setterinherited
    runtimeType Type
    A representation of the runtime type of the object.
    no setterinherited
    sentence String
  • 原始 sentence 文本。
  • final
    translations List<String>
  • 翻译之后的文本。部分翻译提供商提供多个翻译。
  • final

    Methods

    noSuchMethod(Invocation invocation) → dynamic
    Invoked when a nonexistent method or property is accessed.
    inherited
    toString() String
    A string representation of this object.
    inherited

    Operators

    operator ==(Object other) bool
    The equality operator.
    inherited