WordInfo class

单词查询信息结构。

Constructors

WordInfo({required String normalizedWord, required String displayWord, required List<WordTranslation> translations, required List shapes, required Uint8List audioData, required Map<String, dynamic> extendedInfo})
const

Properties

audioData Uint8List
  • word 的发音数据。
  • final
    displayWord String
    1.1 用于常见显示的 word,通常处理大小写。
    final
    extendedInfo Map<String, dynamic>
  • 扩展信息。
  • final
    hashCode int
    The hash code for this object.
    no setterinherited
    normalizedWord String
  • 传入 word 标准化之后的形式,word 表中唯一标识。
  • final
    runtimeType Type
    A representation of the runtime type of the object.
    no setterinherited
    shapes List
  • 单词其他变体形式,例如复数、过去式等。
  • final
    translations List<WordTranslation>
  • word 翻译。
  • final

    Methods

    noSuchMethod(Invocation invocation) → dynamic
    Invoked when a nonexistent method or property is accessed.
    inherited
    toString() String
    A string representation of this object.
    inherited

    Operators

    operator ==(Object other) bool
    The equality operator.
    inherited