WordTranslation class
单词翻译结果结构。
Constructors
Properties
- display → String
-
用于常见显示的翻译。
final
-
examples
→ List<
Map< String, dynamic> > -
2.4 翻译的例句。
final
- frequency → double
-
2.3 翻译频率,数据格式如 10.3(显示为 10.3%)。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- normalized → String
-
2.1 标准化之后的翻译。
final
- posTag → (String, String)
-
2.2 翻译词性, 是 part-of-speech tag 的简写,形如 ("Adjectives", "形容词")。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited